public inbox for gcc-patches@gcc.gnu.org
 help / color / mirror / Atom feed
* PATCH: Support unknown Intel family 0x6 CPUs
@ 2011-06-08 13:48 H.J. Lu
  2011-06-08 14:00 ` Uros Bizjak
  0 siblings, 1 reply; 2+ messages in thread
From: H.J. Lu @ 2011-06-08 13:48 UTC (permalink / raw)
  To: gcc-patches; +Cc: Uros Bizjak

Hi,

This patch supports unknown Intel family 0x6 CPUs.  OK for trunk and
4.6 branch?

Thanks.

H.J.
--
2011-06-08  H.J. Lu  <hongjiu.lu@intel.com>

	* config/i386/driver-i386.c (host_detect_local_cpu): Support
	unknown Intel family 0x6 CPUs.

diff --git a/gcc/config/i386/driver-i386.c b/gcc/config/i386/driver-i386.c
index 4fc6b45..985a6ff 100644
--- a/gcc/config/i386/driver-i386.c
+++ b/gcc/config/i386/driver-i386.c
@@ -587,9 +587,22 @@ const char *host_detect_local_cpu (int argc, const char **argv)
 	default:
 	  if (arch)
 	    {
-	      if (has_ssse3)
-		/* If it is an unknown CPU with SSSE3, assume Core 2.  */
-		cpu = "core2";
+	      /* This is unknown family 0x6 CPU.  */
+	      if (has_avx)
+		/* Assume Sandy Bridge.  */
+		cpu = "corei7-avx";
+	      else if (has_sse4_2)
+		/* Assume Core i7.  */
+		cpu = "corei7";
+	      else if (has_ssse3)
+		{
+		  if (has_movbe)
+		    /* Assume Atom.  */
+		    cpu = "atom";
+		  else
+		    /* Assume Core 2.  */
+		    cpu = "core2";
+		}
 	      else if (has_sse3)
 		/* It is Core Duo.  */
 		cpu = "pentium-m";

^ permalink raw reply	[flat|nested] 2+ messages in thread

* Re: PATCH: Support unknown Intel family 0x6 CPUs
  2011-06-08 13:48 PATCH: Support unknown Intel family 0x6 CPUs H.J. Lu
@ 2011-06-08 14:00 ` Uros Bizjak
  0 siblings, 0 replies; 2+ messages in thread
From: Uros Bizjak @ 2011-06-08 14:00 UTC (permalink / raw)
  To: H.J. Lu; +Cc: gcc-patches

On Wed, Jun 8, 2011 at 3:20 PM, H.J. Lu <hongjiu.lu@intel.com> wrote:
> Hi,
>
> This patch supports unknown Intel family 0x6 CPUs.  OK for trunk and
> 4.6 branch?
>
> Thanks.
>
> H.J.
> --
> 2011-06-08  H.J. Lu  <hongjiu.lu@intel.com>
>
>        * config/i386/driver-i386.c (host_detect_local_cpu): Support
>        unknown Intel family 0x6 CPUs.

OK.

Thanks,
Uros.

^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2011-06-08 13:35 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2011-06-08 13:48 PATCH: Support unknown Intel family 0x6 CPUs H.J. Lu
2011-06-08 14:00 ` Uros Bizjak

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).